..  _`Usage Demos`:

-----------
Usage Demos
-----------

These screencasts show how to use CumulusCI from a command line.

For a live demo with voiceover, please see 
Jason Lantz's 
`Pycon 2020 presentation <https://www.youtube.com/watch?v=XL77lRTVF3g>`_
which gives more context about CumulusCI from about minute 36 through minute 54.

.. raw:: html

      <!-- https://stackoverflow.com/a/58399508/113477 -->
    <link rel="stylesheet"
        type="text/css"
        href="https://cdnjs.cloudflare.com/ajax/libs/asciinema-player/2.4.1/asciinema-player.min.css" />
    <script src="https://cdn.jsdelivr.net/npm/asciinema-player@2.6.1/resources/public/js/asciinema-player.min.js"></script>

This screencast shows how to initialize a fresh CumulusCI project:

.. raw:: html

    <asciinema-player preload="True" poster="npt:0:01" src="https://raw.githubusercontent.com/SFDO-Tooling/cci-demo-animations/master/build/1_setup.cast"></asciinema-player>

The next one shows how to use CumulusCI to retrieve Metadata from a Salesforce org and save it in github.

.. raw:: html

    <asciinema-player preload="True" poster="npt:0:01" src="https://raw.githubusercontent.com/SFDO-Tooling/cci-demo-animations/master/build/2_retrieve_changes.cast"></asciinema-player>

The next screencast shows how to use CCI to manage sample or test data.

.. raw:: html

    <asciinema-player preload="True" poster="npt:0:01" src="https://raw.githubusercontent.com/SFDO-Tooling/cci-demo-animations/master/build/3_populate_data.cast"></asciinema-player>

The final screencast shows how to customize CumulusCI flows and how to use CumulusCI for QA.

.. raw:: html

    <asciinema-player preload="True" poster="npt:0:01" src="https://raw.githubusercontent.com/SFDO-Tooling/cci-demo-animations/master/build/4_qa_org.cast"></asciinema-player>
